@@ -2,13 +2,30 @@
 
 namespace Interop\Http\Factory;
 
+use RuntimeException;
+use function fopen;
+use function fwrite;
+use function is_file;
+use function rewind;
+use function sys_get_temp_dir;
+use function tempnam;
+use function unlink;
+
 trait StreamHelper
 {
     protected static $tempFiles = [];
 
     protected function createTemporaryFile()
     {
-        return static::$tempFiles[] = tempnam(sys_get_temp_dir(), 'http_factory_tests_');
+        $file = tempnam(sys_get_temp_dir(), 'http_factory_tests_');
+
+        if($file === false){
+            throw new RuntimeException('could not create temp file');
+        }
+
+        static::$tempFiles[] = $file;
+
+        return $file;
     }
 
     protected function createTemporaryResource($content = null)
